========================
Change log for batou_scm
========================

1.2 (2026-02-24)
================

- Change git default branch in ``.source.Source`` from ``master`` to ``main``.

- Add support for Python 3.10.+

- Drop support for Python 3.6. to 3.8.

- Replace use of `pkg_resources`.


1.1 (2021-01-29)
================

- Use Github actions as CI.

- Claim support for Python 3.9.

- Fix bug in ``.buildout.Buildout`` where it was not always updated when a
  source has changed.


1.0 (2020-07-16)
================

- Update default setup tools version to latest release.

- Require a final release of batou version 2.


1.0b2 (2020-06-15)
==================

- Update default versions used in Buildout component to recent versions.


1.0b1 (2020-05-08)
==================

- Add support for Python 3.6 up to 3.8.

- Require ``batou >= 2``.

- Drop support for Python 2.7.

- Migrate repository to github.


0.6.3 (2018-05-04)
==================

- Remove bitbucket.org fingerprint.


0.6.2 (2018-05-04)
==================

- Update bitbucket.org fingerprint again.

- Remove `code.gocept.com` from fingerprints.


0.6.1 (2018-05-04)
==================

- Update bitbucket.org fingerprint.


0.6 (2017-11-29)
================

- Update to `batou >= 1.6` and `pytest >= 3.3`.


0.5 (2017-11-13)
================

- Remove absolute path in setup.py.


0.4 (2017-05-30)
================

- Fix `has_changes` detection of clone in buildout component.
  This requires `batou >= 1.3`.


0.3.2 (2016-05-09)
==================

- Fixed compatibility with pre-1.1 batou.


0.3.1 (2016-05-09)
==================

- Update bitbucket.org fingerprint.

- Require current batou for tests while keeping code compatible with pre-1.0.


0.3 (2016-04-15)
================

- Use ``zc.buildout == 2.5.0`` and ``setuptools == 20.7`` as default versions.

- Drop support for Python 2.6.


0.2 (2015-09-21)
================

- Add ``BuildoutWithVersionPins`` to be able to handle version pinnings in a
  separate source package.


0.1.3 (2015-05-21)
==================

- Update bitbucket.org fingerprint.


0.1.2 (2015-01-12)
==================

- Make ``Buildout.eggs_directory`` path configurable.


0.1.1 (2014-11-28)
==================

- Update code.gocept.com fingerprint.


0.1 (2014-08-28)
================

- initial release
